Overview
========

aeolus is a Python library for the analysis and visualisation of climate model output, primarily the UK Met Office Unified Model. It leverages the functionality of `iris`_ and has modules geared towards working with 3D general circulation models of planetary atmospheres.

Contents
--------
.. toctree::
   :maxdepth: 1
   :glob:

   install
   examples/index.rst
   api/index.rst
   changelog
   contributing


See also
--------

- The `iris <https://scitools-iris.readthedocs.io/en/stable/>`_ package, upon which aeolus relies heavily.
- The repository with `code <https://github.com/dennissergeev/t1e_bistability_code>`_ used in `Sergeev et al. (2022) <https://arxiv.org/abs/2207.12342>`_.
- The repository with `code <https://github.com/dennissergeev/exoconvection-apj-2020>`_ used in `Sergeev et al. (2020) <https://arxiv.org/abs/2004.03007>`_.
- The repository with `code <https://github.com/mzamyatina/signatures_of_wind_driven_chemistry_on_hot_jupiters>`_ used in `Zamyatina et al. (2023) <https://doi.org/10.1093/mnras/stac3432>`_.


License
-------
Aeolus is released under the terms of the LGPL-3.0 license.


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
